<template>
	<div class="pc-mouldboard column exampleSlide" v-show="isShowAdvanceExample">
		<div class="header flex items-center justify-center">
			<div
				class="box-border flex w-[203px] h-[32px] rounded-md items-center justify-between cursor-pointer relative border border-solid border-[#2c2d33]"
			>
				<div
					class="tabbar-item"
					:class="state.activeName === item.ID ? 'set-tabbar-active' : ''"
					@click="handleTabClick(item)"
					v-for="item in state.tabNameList"
					:key="item.ID"
				>
					{{ item.Name }}
				</div>
			</div>
			<i
				class="ywicon icon-guanbi text-[#999] text-[18px] absolute right-[14px] top-5 cursor-pointer"
				@click="handleCloseTemplate"
			></i>
		</div>

		<div class="box-border w-[354px] flex-1 min-h-0 bg-[#e0e7fb]" v-show="state.activeName == 1">
			<div class="flex flex-col w100 h100 pt-0 pr-[15px] pb-0 pl-[20px] overflow-auto">
				<div class="flex items-center w100 h-[30px] border border-solid border-[#b2b2b2] transition-[border-color 1s] rounded-2xl">
					<el-input v-model="queryParams.sample_title" placeholder="搜索更多" class="set-input" :prefix-icon="Search" clearable>
					</el-input>
				</div>
				<div class="mt20 w100 relative">
					<div
						class="overflow-hidden max-h-[36px] transition-[max-height 0.2s] w100 flex flex-wrap text-xs leading-[14px] m-[-5px]"
						:class="{ 'set-expand-active': state.isShowExpand }"
					>
						<div
							v-for="item in state.exampleTabList"
							:key="item.ID"
							:class="{ 'set-label-active': state.activeLabelName === item.ID }"
							@click="handleLabelClick(item)"
							class="cursor-pointer m-[5px] py-[5px] px-[10px] rounded-xl border border-solid border-[#b2b2b2] bg-[#e0e7f] text-[#4c4c4c] transition-[background-color .1s, color .1s, border-color .1s]"
						>
							{{ item.Title }}
						</div>
					</div>
					<div class="bg-[#e0e7fb] absolute right-0 top-0 text-[#131313] w-[30px] h-[26px] cursor-pointer flex items-center">
						<i class="iconfont icon-bolangneng" title="展开" @click="handleExpandClick(1)" v-show="!state.isShowExpand"></i>
						<i class="iconfont icon-zhongduancanshu" title="收缩" @click="handleExpandClick(2)" v-show="state.isShowExpand"></i>
					</div>
					<div class="mt20 w100">
						<div class="w100 pb-[20px]" v-for="item in queryData" :key="item.sample_id">
							<div
								class="cursor-pointer flex box-border p-[12px] w100 rounded bg-[#f5f7fd] transition-[background-color .2s]"
								@click="changeExample(item)"
							>
								<i
									class="iconfont icon-chazhaobiaodanliebiao pl-[2px] w-[16px] h-[16px] font12 text-[#fff] transform-[scale(.85)] rounded-[50%]"
									:style="`background-color:${item.BgColor}`"
								></i>
								<div class="ml-6 flex-1 min-w-0">
									<div class="text-sm text-[#000] m-0 p-0 font-bold">{{ item.sample_title }}</div>
									<div class="mt-[6px] text-[13px] text-[#666] h-[20px] whitespace-nowrap text-ellipsis overflow-hidden">
										{{ item.sample_question }}
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
		<div class="box-border w-[354px] flex-1 min-h-0 bg-[#e0e7fb]" v-show="state.activeName == 2">
			<div class="flex flex-col w100 h100 pt-0 pr-[15px] pb-0 pl-[20px] overflow-auto">
				<div class="flex items-center w100 h-[30px] border border-solid border-[#b2b2b2] transition-[border-color 1s] rounded-2xl">
					<el-input v-model="instructParams.template_title" placeholder="搜索更多" class="set-input" :prefix-icon="Search" clearable>
					</el-input>
				</div>
				<div class="mt20 w100 relative">
					<div
						class="overflow-hidden max-h-[36px] transition-[max-height 0.2s] w100 flex flex-wrap text-xs leading-[14px] m-[-5px]"
						:class="{ 'set-expand-active': state.isShowExpand }"
					>
						<div
							v-for="item in state.instructList"
							:key="item.ID"
							:class="{ 'set-label-active': state.activeInstructName === item.ID }"
							@click="handleInstructClick(item)"
							class="cursor-pointer m-[5px] py-[5px] px-[10px] rounded-xl border border-solid border-[#b2b2b2] bg-[#e0e7f] text-[#4c4c4c] transition-[background-color .1s, color .1s, border-color .1s]"
						>
							{{ item.Title }}
						</div>
					</div>
					<div class="bg-[#e0e7fb] absolute right-0 top-0 text-[#131313] w-[30px] h-[26px] cursor-pointer flex items-center">
						<i class="iconfont icon-bolangneng" title="展开" @click="handleExpandClick(1)" v-show="!state.isShowExpand"></i>
						<i class="iconfont icon-zhongduancanshu" title="收缩" @click="handleExpandClick(2)" v-show="state.isShowExpand"></i>
					</div>
					<div class="mt20 w100">
						<div class="w100 pb-[20px] flex overflow-auto flex-col" v-for="item in showInstructList" :key="item.template_id">
							<div class="bg-[#f5f7fd] p-[12px] transition-[background-color .2s] flex flex-col rounded-2xl">
								<div class="flex justify-between">
									<span class="set-title">{{ item.template_title }}</span>
								</div>
								<div class="example-body ellipsis">{{ item.template_value }}</div>
								<div class="example-bottom">
									<span class="example-item">{{ item.template_type }}</span>
									<el-button type="primary" class="set-button" @click="templateUseClick(item)">使用</el-button>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>

		<el-dialog v-model="state.useInstructDialog" :title="state.instructInfo?.template_title" width="500" :before-close="handleClose">
			<el-input v-model="state.inputInstruct" :rows="10" type="textarea"></el-input>
			<template #footer>
				<div class="dialog-footer">
					<el-button @click="handleClose">取消</el-button>
					<el-button type="primary" @click="submitInstruct"> 确认 </el-button>
				</div>
			</template>
		</el-dialog>
	</div>
</template>

<script setup lang="ts">
import { Search } from '@element-plus/icons-vue';
import { onMounted, reactive, ref, toRefs, watch } from 'vue';
import { getSelectSample, getUserTemplateList } from '/@/api/ai/chat';
import { useSearch } from '/@/hooks/useSearch';
import { activeRoomId, activeSampleId, setRoomConfig } from '/@/stores/chatRoom';
import emitter from '/@/utils/mitt';
import { debounce } from '/@/utils/util';
let state = reactive({
	tabNameList: [
		{ ID: 1, Name: '提问示例' },
		{ ID: 2, Name: '指令模板' },
	],
	activeName: 1,
	exampleTabList: [
		{
			ID: 1,
			Title: '工作',
		},
		{
			ID: 2,
			Title: '职场',
		},
		{
			ID: 3,
			Title: '科学',
		},
		{
			ID: 4,
			Title: '求职',
		},
		{
			ID: 5,
			Title: '新能源,汽车,数据',
		},
		{
			ID: 6,
			Title: '写作',
		},
		{
			ID: 7,
			Title: '学习',
		},
		{
			ID: 8,
			Title: '创作',
		},
	],
	instructList: [
		{
			ID: 1,
			Title: '文学构思',
		},
		{
			ID: 2,
			Title: '语言翻译',
		},
		{
			ID: 3,
			Title: '高效策划',
		},
		{
			ID: 4,
			Title: '顾问专家',
		},
		{
			ID: 5,
			Title: '代码编程',
		},
		{
			ID: 6,
			Title: '办公写作',
		},
		{
			ID: 7,
			Title: '健康管家',
		},
		{
			ID: 8,
			Title: '发现探索',
		},
	],
	activeLabelName: 0,
	activeInstructName: 0,
	isShowExpand: false,
	useInstructDialog: false,
	instructInfo: {},
	inputInstruct: '', //可修改指令
	exampleRandomContent: [],
	exampleContent: [],
});
const instructContentList = ref([]); //指令列表
const exampleList = ref([]); //示例列表
const props = defineProps({
	isShowAdvanceExample: {
		type: Boolean,
		default: false, //是否显示高级示例
	},
});
const { isShowAdvanceExample } = toRefs(props);
onMounted(() => {
	getSelectListSample();
	getUserTemplate();
});
const emits = defineEmits<{
	(event: 'closeExampleClick', data): void;
}>();
//获取模版列表
const getSelectListSample = async () => {
	const res = await getSelectSample({
		section_b_id: '',
	});
	// console.log(res, 63);
	state.exampleRandomContent = res.samples;

	const array = [];
	res.samples.forEach((sample, index) => {
		sample.Icon = '/static/images/wave/ChatImg.png';
		sample.BgColor = randomHexColor();
		if (index < 4) {
			array.push(sample);
		}
	});
	exampleList.value = res.samples;
	state.exampleContent = array;
};
//随机生成颜色
const randomHexColor = () => {
	return `#${Math.floor(Math.random() * 16777215)
		.toString(16)
		.padEnd(6, '0')}`;
};
const changeExample = (item) => {
	emitter.emit('updateChatInput', item.sample_question);
	setRoomConfig(activeRoomId.value, 'isAnswerByLLM', false);
	activeSampleId.value = item.sample_id;
};
//获取用户模板
const getUserTemplate = async () => {
	const res = await getUserTemplateList();
	instructContentList.value = res.templates;
};
//切换到指令/提问
const handleTabClick = (item) => {
	state.activeName = item.ID;
};
//标签点击事件(提问示例)
const handleLabelClick = (item) => {
	state.activeLabelName = item.ID;
};
//标签点击事件(指令模板)
const handleInstructClick = (item) => {
	state.activeInstructName = item.ID;
};

//展开收起
const handleExpandClick = (type) => {
	if (type == 1) {
		state.isShowExpand = true;
	} else {
		state.isShowExpand = false;
	}
};
//关闭高级示例
const handleCloseTemplate = () => {
	emits('closeExampleClick', false);
};
//#region ====================== templateUseClick ======================
const templateUseClick = (row) => {
	state.useInstructDialog = true;
	state.instructInfo = row;
	state.inputInstruct = row.template_value;
};
const handleClose = () => {
	state.useInstructDialog = false;
};
const submitInstruct = () => {
	setRoomConfig(activeRoomId.value, 'isAnswerByLLM', true);
	emitter.emit('updateChatInput', state.inputInstruct);
	handleClose();
};
//#endregion
//#region ====================== 搜索模板/指令 ======================
const queryParams = ref({
	sample_title: '',
});
const { query, queryData } = useSearch(exampleList, queryParams);

const debounceQuery = debounce(query);

watch(
	() => queryParams.value.sample_title,
	(val) => {
		debounceQuery();
	}
);
//指令
const instructParams = ref({
	template_title: '',
});
const { query: queryInstruct, queryData: showInstructList } = useSearch(instructContentList, instructParams);

const instructQuery = debounce(queryInstruct);

watch(
	() => instructParams.value.template_title,
	(val) => {
		instructQuery();
	}
);
//#endregion
</script>
<style scoped lang="scss">
.exampleSlide {
	// position: absolute;
	right: 0;
	top: 0;
	height: 100%;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	z-index: 100;
}

.pc-mouldboard {
	width: 354px;
	font-size: 14px;
	-webkit-animation: right-c650b75e 0.2s;
	animation: right-c650b75e 0.2s;

	.header {
		box-sizing: border-box;
		width: 100%;
		background-color: #e0e7fb;
		padding: 30px 20px 26px;
		position: relative;
	}
	.tabbar-item {
		width: 108px;
		height: 30px;
		font-size: 13px;
		font-weight: 400;
		line-height: 30px;
		text-align: center;
		cursor: pointer;
		// position: absolute;
		-o-transition: color 0.2s;
		transition: color 0.2s;
		&:nth-child(3) {
			top: 0;
			left: 0;
		}
	}
	.tabbar-item-active {
		color: #fff;
	}
	.set-tabbar-active {
		left: 95px;
		color: #fff;
		background-color: #000;
	}
	.set-input {
		:deep(.el-input__wrapper) {
			border: none;
			outline: none;
			-webkit-box-flex: 1;
			-ms-flex: 1;
			flex: 1;
			min-width: 0;
			height: 100%;
			-webkit-box-sizing: border-box;
			box-sizing: border-box;
			padding: 5px 12px;
			line-height: 20px;
			border-radius: 15px;
			color: #555;
			font-size: 13px;
			background-color: transparent;
			box-shadow: unset;
		}
	}
	.set-expand-active {
		max-height: 180px;
	}
	.set-label-active {
		border-color: #1c86ff;
		background-color: #ccdcfb;
		color: #1c86ff;
	}
	.example-body {
		margin: 10px 0;
		height: 40px;
		font-weight: 400;
		letter-spacing: 0;
		line-height: 20px;
		color: #8b939e;
	}
	.ellipsis {
		display: -webkit-box;
		-webkit-line-clamp: 2;
		-webkit-box-orient: vertical;
		overflow: hidden;
		-o-text-overflow: ellipsis;
		text-overflow: ellipsis;
		font-size: 12px;
	}
	.example-bottom {
		margin-top: 10px;
		display: flex;
		-webkit-box-pack: justify;
		-ms-flex-pack: justify;
		justify-content: space-between;
		.example-item {
			background-color: #f0f2f3;
			color: #8b939e;
			border: 1px solid #f5f5f5;
			border-radius: 9px;
			width: 58px;
			height: 18px;
			font-size: 12px;
			line-height: 18px;
			text-align: center;
			cursor: default;
			margin-left: 5px;
		}
		.set-button {
			border: none;
			width: 68px;
			height: 24px;
			color: #fff;
			font-size: 12px;
			background-color: #2a82e4;
			border-radius: 4px;
			cursor: pointer;
		}
	}
}
.column {
	display: flex;
	-webkit-box-orient: vertical;
	-webkit-box-direction: normal;
	-ms-flex-direction: column;
	flex-direction: column;
}
</style>
